@@ -3,6 +3,6 @@ from .metaApi.historyStorage import HistoryStorage
 from .metaApi.memoryHistoryStorage import MemoryHistoryStorage
 from .clients.metaApi.synchronizationListener import SynchronizationListener
 from .metaApi.models import format_error, format_date, date
-from metaapi_cloud_copyfactory_sdk import CopyFactory, StopoutListener
+from metaapi_cloud_copyfactory_sdk import CopyFactory, StopoutListener, UserLogListener, TransactionListener
 from metaapi_cloud_metastats_sdk import MetaStats
 from metaapi_cloud_risk_management_sdk import RiskManagement, DrawdownListener
