@@ -120,6 +120,13 @@ class MockAccount(MetatraderAccount):
     async def reload(self):
         pass
 
+    @property
+    def account_regions(self) -> dict:
+        return {
+            'vint-hill': 'accountId',
+            'new-york': 'accountIdReplica'
+        }
+
 
 class AutoMockAccount(MetatraderAccount):
     @property
@@ -152,6 +159,9 @@ async def run_around_tests():
                                    'MetaApi')
     global client
     client = MockClient(MagicMock(), 'token')
+    client.get_url_settings = AsyncMock()
+    client.ensure_subscribe = AsyncMock()
+    client.subscribe = AsyncMock()
     global storage
     storage = MagicMock()
     storage.initialize = AsyncMock()
@@ -500,15 +510,15 @@ class TestStreamingMetaApiConnection:
     async def test_subscribe_to_terminal(self):
         """Should subscribe to terminal."""
         await api.connect()
-        client.ensure_subscribe = AsyncMock()
         await api.subscribe()
         client.ensure_subscribe.assert_any_call('accountId', 0)
         client.ensure_subscribe.assert_any_call('accountId', 1)
+        client.ensure_subscribe.assert_any_call('accountIdReplica', 0)
+        client.ensure_subscribe.assert_any_call('accountIdReplica', 1)
 
     @pytest.mark.asyncio
     async def test_not_subscribe_if_not_open(self):
         """Should not subscribe if connection is not open."""
-        client.ensure_subscribe = AsyncMock()
         try:
             await api.subscribe()
             pytest.fail()
@@ -538,14 +548,14 @@ class TestStreamingMetaApiConnection:
         with patch('lib.metaApi.streamingMetaApiConnection.random_id', return_value='synchronizationId'):
             api = StreamingMetaApiConnection(client, client_api_client, account, None, MagicMock())
             await api.connect()
-            await api.history_storage.on_history_order_added('1:ps-mpa-1',
+            await api.history_storage.on_history_order_added('vint-hill:1:ps-mpa-1',
                                                              {'id': '1', 'type': 'ORDER_TYPE_SELL',
                                                               'state': 'ORDER_STATE_FILLED',
                                                               'doneTime': date('2020-01-01T00:00:00.000Z')})
-            await api.history_storage.on_deal_added('1:ps-mpa-1', {'id': '1', 'type': 'DEAL_TYPE_SELL',
-                                                                   'entryType': 'DEAL_ENTRY_IN',
-                                                                   'time': date('2020-01-02T00:00:00.000Z')})
-            await api.synchronize('1:ps-mpa-1')
+            await api.history_storage.on_deal_added('vint-hill:1:ps-mpa-1', {'id': '1', 'type': 'DEAL_TYPE_SELL',
+                                                                             'entryType': 'DEAL_ENTRY_IN',
+                                                                             'time': date('2020-01-02T00:00:00.000Z')})
+            await api.synchronize('vint-hill:1:ps-mpa-1')
             client.synchronize.assert_called_with('accountId', 1, 'ps-mpa-1', 'synchronizationId',
                                                   date('2020-01-01T00:00:00.000Z'), date('2020-01-02T00:00:00.000Z'),
                                                   ANY)
@@ -558,14 +568,14 @@ class TestStreamingMetaApiConnection:
             api = StreamingMetaApiConnection(client, client_api_client, account, None, MagicMock(),
                                              date('2020-10-07T00:00:00.000Z'))
             await api.connect()
-            await api.history_storage.on_history_order_added('1:ps-mpa-1',
+            await api.history_storage.on_history_order_added('vint-hill:1:ps-mpa-1',
                                                              {'id': '1', 'type': 'ORDER_TYPE_SELL',
                                                               'state': 'ORDER_STATE_FILLED',
                                                               'doneTime': date('2020-01-01T00:00:00.000Z')})
-            await api.history_storage.on_deal_added('1:ps-mpa-1', {'id': '1', 'type': 'DEAL_TYPE_SELL',
-                                                                   'entryType': 'DEAL_ENTRY_IN',
-                                                                   'time': date('2020-01-02T00:00:00.000Z')})
-            await api.synchronize('1:ps-mpa-1')
+            await api.history_storage.on_deal_added('vint-hill:1:ps-mpa-1', {'id': '1', 'type': 'DEAL_TYPE_SELL',
+                                                                             'entryType': 'DEAL_ENTRY_IN',
+                                                                             'time': date('2020-01-02T00:00:00.000Z')})
+            await api.synchronize('vint-hill:1:ps-mpa-1')
             client.synchronize.assert_called_with('accountId', 1, 'ps-mpa-1', 'synchronizationId',
                                                   date('2020-10-07T00:00:00.000Z'), date('2020-10-07T00:00:00.000Z'),
                                                   ANY)
@@ -635,7 +645,8 @@ class TestStreamingMetaApiConnection:
         await api.connect()
         api.subscribe_to_market_data = AsyncMock()
         api.unsubscribe_from_market_data = AsyncMock()
-        await api.on_subscription_downgraded('1:ps-mpa-1', 'EURUSD', None, [{'type': 'ticks'}, {'type': 'books'}])
+        await api.on_subscription_downgraded('vint-hill:1:ps-mpa-1', 'EURUSD', None,
+                                             [{'type': 'ticks'}, {'type': 'books'}])
         api.unsubscribe_from_market_data.assert_called_with('EURUSD', [{'type': 'ticks'}, {'type': 'books'}])
         api.subscribe_to_market_data.assert_not_called()
 
@@ -645,7 +656,7 @@ class TestStreamingMetaApiConnection:
         await api.connect()
         api.subscribe_to_market_data = AsyncMock()
         api.unsubscribe_from_market_data = AsyncMock()
-        await api.on_subscription_downgraded('1:ps-mpa-1', 'EURUSD',
+        await api.on_subscription_downgraded('vint-hill:1:ps-mpa-1', 'EURUSD',
                                              [{'type': 'quotes', 'intervalInMilliseconds': 30000}])
         api.subscribe_to_market_data.assert_called_with('EURUSD', [{'type': 'quotes', 'intervalInMilliseconds': 30000}])
         api.unsubscribe_from_market_data.assert_not_called()
@@ -699,7 +710,7 @@ class TestStreamingMetaApiConnection:
             storage.last_history_order_time = AsyncMock(return_value=date('2020-01-01T00:00:00.000Z'))
             storage.last_deal_time = AsyncMock(return_value=date('2020-01-02T00:00:00.000Z'))
             await api.connect()
-            await api.on_connected('1:ps-mpa-1', 1)
+            await api.on_connected('vint-hill:1:ps-mpa-1', 1)
             await asyncio.sleep(0.05)
             client.synchronize.assert_called_with('accountId', 1, 'ps-mpa-1', 'synchronizationId',
                                                   date('2020-01-01T00:00:00.000Z'), date('2020-01-02T00:00:00.000Z'),
@@ -714,7 +725,7 @@ class TestStreamingMetaApiConnection:
             await api.connect()
             storage.last_history_order_time = AsyncMock(return_value=date('2020-01-01T00:00:00.000Z'))
             storage.last_deal_time = AsyncMock(return_value=date('2020-01-02T00:00:00.000Z'))
-            await api.on_connected('1:ps-mpa-1', 1)
+            await api.on_connected('vint-hill:1:ps-mpa-1', 1)
             await asyncio.sleep(0.05)
             client.synchronize.assert_called_with('accountId', 1,  'ps-mpa-1', 'synchronizationId',
                                                   date('2020-01-01T00:00:00.000Z'), date('2020-01-02T00:00:00.000Z'),
@@ -728,11 +739,11 @@ class TestStreamingMetaApiConnection:
             client.unsubscribe = AsyncMock()
             api = StreamingMetaApiConnection(client, client_api_client, account, storage, MagicMock())
             await api.connect()
-            await api.history_storage.on_history_order_added('1:ps-mpa-1',
+            await api.history_storage.on_history_order_added('vint-hill:1:ps-mpa-1',
                                                              {'doneTime': date('2020-01-01T00:00:00.000Z')})
-            await api.history_storage.on_deal_added('1:ps-mpa-1', {'time': date('2020-01-02T00:00:00.000Z')})
+            await api.history_storage.on_deal_added('vint-hill:1:ps-mpa-1', {'time': date('2020-01-02T00:00:00.000Z')})
             await api.close()
-            await api.on_connected('1:ps-mpa-1', 1)
+            await api.on_connected('vint-hill:1:ps-mpa-1', 1)
             client.synchronize.assert_not_called()
 
     @pytest.mark.asyncio
@@ -753,8 +764,9 @@ class TestStreamingMetaApiConnection:
     @pytest.mark.asyncio
     async def test_wait_sync_complete_user_mode(self):
         """Should wait until synchronization complete."""
+        client.wait_synchronized = AsyncMock()
         await api.connect()
-        assert not (await api.is_synchronized('1:ps-mpa-1'))
+        assert not (await api.is_synchronized('vint-hill:1:ps-mpa-1'))
         api._historyStorage.update_disk_storage = AsyncMock()
         try:
             await api.wait_synchronized({'applicationPattern': 'app.*', 'synchronizationId': 'synchronizationId',
@@ -762,14 +774,39 @@ class TestStreamingMetaApiConnection:
             raise Exception('TimeoutError is expected')
         except Exception as err:
             assert err.__class__.__name__ == 'TimeoutException'
-        await api.on_history_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
-        await api.on_deals_synchronized('1:ps-mpa-1', 'synchronizationId')
+        await api.on_history_orders_synchronized('vint-hill:1:ps-mpa-1', 'synchronizationId')
+        await api.on_deals_synchronized('vint-hill:1:ps-mpa-1', 'synchronizationId')
         promise = api.wait_synchronized({'applicationPattern': 'app.*', 'synchronizationId': 'synchronizationId',
                                          'timeoutInSeconds': 1, 'intervalInMilliseconds': 10})
         start_time = datetime.now()
         await promise
         assert pytest.approx(10, 10) == (datetime.now() - start_time).seconds * 1000
-        assert (await api.is_synchronized('1:ps-mpa-1', 'synchronizationId'))
+        assert (await api.is_synchronized('vint-hill:1:ps-mpa-1', 'synchronizationId'))
+        client.wait_synchronized.assert_called_with('accountId', 1, 'app.*', ANY)
+
+    @pytest.mark.timeout(60)
+    @pytest.mark.asyncio
+    async def test_wait_sync_complete_replica(self):
+        """Should wait synchronize on a replica."""
+        client.wait_synchronized = AsyncMock()
+        await api.connect()
+        assert not (await api.is_synchronized('new-york:1:ps-mpa-1'))
+        api._historyStorage.update_disk_storage = AsyncMock()
+        try:
+            await api.wait_synchronized({'applicationPattern': 'app.*', 'synchronizationId': 'synchronizationId',
+                                         'timeoutInSeconds': 1, 'intervalInMilliseconds': 10})
+            raise Exception('TimeoutError is expected')
+        except Exception as err:
+            assert err.__class__.__name__ == 'TimeoutException'
+        await api.on_history_orders_synchronized('new-york:1:ps-mpa-1', 'synchronizationId')
+        await api.on_deals_synchronized('new-york:1:ps-mpa-1', 'synchronizationId')
+        promise = api.wait_synchronized({'applicationPattern': 'app.*', 'synchronizationId': 'synchronizationId',
+                                         'timeoutInSeconds': 1, 'intervalInMilliseconds': 10})
+        start_time = datetime.now()
+        await promise
+        assert pytest.approx(10, 10) == (datetime.now() - start_time).seconds * 1000
+        assert (await api.is_synchronized('new-york:1:ps-mpa-1', 'synchronizationId'))
+        client.wait_synchronized.assert_called_with('accountIdReplica', 1, 'app.*', ANY)
 
     @pytest.mark.asyncio
     async def test_time_out_waiting_for_sync(self):
@@ -781,27 +818,29 @@ class TestStreamingMetaApiConnection:
             raise Exception('TimeoutError is expected')
         except Exception as err:
             assert err.__class__.__name__ == 'TimeoutException'
-        assert not (await api.is_synchronized('1:ps-mpa-1', 'synchronizationId'))
+        assert not (await api.is_synchronized('vint-hill:1:ps-mpa-1', 'synchronizationId'))
 
     @pytest.mark.asyncio
-    async def test_load_history_storage_from_disk(self):
-        """Should load data to history storage from disk."""
+    async def test_initialize_connection(self):
+        """Should initialize connection."""
+        client.add_account_cache = MagicMock()
         await api.connect()
         api._historyStorage.initialize = AsyncMock()
         await api.initialize()
         api._historyStorage.initialize.assert_called()
+        client.add_account_cache.assert_called_with('accountId', {'new-york': 'accountIdReplica',
+                                                                  'vint-hill': 'accountId'})
 
     @pytest.mark.asyncio
     async def test_disconnect(self):
         """Should set synchronized false on disconnect."""
         await api.connect()
         client.synchronize = AsyncMock()
-        await api.on_connected('1:ps-mpa-1', 2)
+        await api.on_connected('vint-hill:1:ps-mpa-1', 2)
         await asyncio.sleep(0.05)
         assert api.synchronized
-        client.subscribe = AsyncMock()
         account.reload = AsyncMock()
-        await api.on_disconnected('1:ps-mpa-1')
+        await api.on_disconnected('vint-hill:1:ps-mpa-1')
         assert not api.synchronized
 
     @pytest.mark.asyncio
@@ -809,10 +848,10 @@ class TestStreamingMetaApiConnection:
         """Should delete state if stream closed."""
         await api.connect()
         client.synchronize = AsyncMock()
-        await api.on_connected('1:ps-mpa-1', 2)
+        await api.on_connected('vint-hill:1:ps-mpa-1', 2)
         await asyncio.sleep(0.05)
         assert api.synchronized
-        await api.on_stream_closed('1:ps-mpa-1')
+        await api.on_stream_closed('vint-hill:1:ps-mpa-1')
         assert not api.synchronized
 
     @pytest.mark.asyncio
@@ -827,7 +866,7 @@ class TestStreamingMetaApiConnection:
                 client.remove_synchronization_listener = MagicMock()
                 client.unsubscribe = AsyncMock()
                 api.terminal_state.wait_for_price = AsyncMock()
-                await api.on_synchronization_started('1:ps-mpa-1')
+                await api.on_synchronization_started('vint-hill:1:ps-mpa-1')
                 await sleep(0.05)
                 client.refresh_market_data_subscriptions.assert_called_with('accountId', 1, [])
                 await api.subscribe_to_market_data('EURUSD', [{'type': 'quotes'}], 1)
@@ -835,13 +874,65 @@ class TestStreamingMetaApiConnection:
                 client.refresh_market_data_subscriptions.assert_called_with(
                     'accountId', 1, [{'symbol': 'EURUSD', 'subscriptions': [{'type': 'quotes'}]}])
                 assert client.refresh_market_data_subscriptions.call_count == 2
-                await api.on_synchronization_started('1:ps-mpa-1')
+                await api.on_synchronization_started('vint-hill:1:ps-mpa-1')
                 await sleep(0.05)
                 assert client.refresh_market_data_subscriptions.call_count == 3
                 await api.close()
                 await sleep(0.11)
                 assert client.refresh_market_data_subscriptions.call_count == 3
 
+    @pytest.mark.asyncio
+    async def test_create_refresh_market_data_subscriptions_job_replica(self):
+        """Should create refresh subscriptions job with a replica."""
+        with patch('lib.metaApi.streamingMetaApiConnection.asyncio.sleep', new=lambda x: sleep(x / 10)):
+            with patch('lib.metaApi.streamingMetaApiConnection.uniform', new=MagicMock(return_value=1)):
+                await api.connect()
+                client.refresh_market_data_subscriptions = AsyncMock()
+                client.subscribe_to_market_data = AsyncMock()
+                client.add_synchronization_listener = MagicMock()
+                client.remove_synchronization_listener = MagicMock()
+                client.unsubscribe = AsyncMock()
+                api.terminal_state.wait_for_price = AsyncMock()
+                await api.on_synchronization_started('new-york:1:ps-mpa-1')
+                await sleep(0.05)
+                client.refresh_market_data_subscriptions.assert_called_with('accountIdReplica', 1, [])
+                await api.subscribe_to_market_data('EURUSD', [{'type': 'quotes'}], 1)
+                await sleep(0.11)
+                client.refresh_market_data_subscriptions.assert_called_with(
+                    'accountIdReplica', 1, [{'symbol': 'EURUSD', 'subscriptions': [{'type': 'quotes'}]}])
+                assert client.refresh_market_data_subscriptions.call_count == 2
+                await api.on_synchronization_started('new-york:1:ps-mpa-1')
+                await sleep(0.05)
+                assert client.refresh_market_data_subscriptions.call_count == 3
+                await api.close()
+                await sleep(0.11)
+                assert client.refresh_market_data_subscriptions.call_count == 3
+
+    @pytest.mark.asyncio
+    async def test_remove_subscription_job_on_region_unsubscribe(self):
+        """Should remove subscription job on region unsubscribe."""
+        with patch('lib.metaApi.streamingMetaApiConnection.asyncio.sleep', new=lambda x: sleep(x / 10)):
+            with patch('lib.metaApi.streamingMetaApiConnection.uniform', new=MagicMock(return_value=1)):
+                await api.connect()
+                client.refresh_market_data_subscriptions = AsyncMock()
+                client.subscribe_to_market_data = AsyncMock()
+                client.add_synchronization_listener = MagicMock()
+                client.remove_synchronization_listener = MagicMock()
+                client.unsubscribe = AsyncMock()
+                api.terminal_state.wait_for_price = AsyncMock()
+                await api.on_synchronization_started('vint-hill:1:ps-mpa-1')
+                await sleep(0.05)
+                client.refresh_market_data_subscriptions.assert_called_with('accountId', 1, [])
+                await api.subscribe_to_market_data('EURUSD', [{'type': 'quotes'}], 1)
+                await sleep(0.11)
+                client.refresh_market_data_subscriptions.assert_called_with(
+                    'accountId', 1, [{'symbol': 'EURUSD', 'subscriptions': [{'type': 'quotes'}]}])
+                assert client.refresh_market_data_subscriptions.call_count == 2
+                await api.on_unsubscribe_region('vint-hill')
+                await sleep(0.11)
+                assert client.refresh_market_data_subscriptions.call_count == 2
+                await api.close()
+
     @pytest.mark.asyncio
     async def test_queue_events(self):
         """Should queue events."""
@@ -852,3 +943,35 @@ class TestStreamingMetaApiConnection:
 
         api.queue_event('test', event_callable)
         client.queue_event.assert_called_with('accountId', 'test', event_callable)
+
+    @pytest.mark.asyncio
+    async def test_clear_region_states_on_socket_reconnect(self):
+        """Should clear region states on socket reconnect."""
+        with patch('lib.metaApi.streamingMetaApiConnection.asyncio.sleep', new=lambda x: sleep(x / 10)):
+            with patch('lib.metaApi.streamingMetaApiConnection.uniform', new=MagicMock(return_value=1)):
+                await api.connect()
+                client.refresh_market_data_subscriptions = AsyncMock()
+                client.subscribe_to_market_data = AsyncMock()
+                client.add_synchronization_listener = MagicMock()
+                client.remove_synchronization_listener = MagicMock()
+                client.unsubscribe = AsyncMock()
+                await api.on_synchronization_started('new-york:1:ps-mpa-1')
+                await api.on_synchronization_started('vint-hill:1:ps-mpa-1')
+                await sleep(0.05)
+                client.refresh_market_data_subscriptions.assert_any_call('accountIdReplica', 1, [])
+                client.refresh_market_data_subscriptions.assert_any_call('accountId', 1, [])
+                await api.terminal_state.on_symbol_prices_updated('new-york:1:ps-mpa-1', [
+                    {'time': datetime.now(), 'symbol': 'EURUSD', 'bid': 1, 'ask': 1.1,
+                     'brokerTime': '2022-01-01 02:00:00.000'}])
+                await api.terminal_state.on_symbol_prices_updated('vint-hill:1:ps-mpa-1', [
+                    {'time': datetime.now(), 'symbol': 'EURUSD', 'bid': 1, 'ask': 1.1,
+                     'brokerTime': '2022-01-01 02:00:00.000'}])
+                await api.subscribe_to_market_data('EURUSD', [{'type': 'quotes'}], 1)
+                await sleep(0.11)
+                assert client.refresh_market_data_subscriptions.call_count == 4
+                await api.on_reconnected('new-york', 1)
+                await sleep(0.11)
+                assert client.refresh_market_data_subscriptions.call_count == 5
+                await api.on_reconnected('vint-hill', 1)
+                await sleep(0.11)
+                assert client.refresh_market_data_subscriptions.call_count == 5
